/* include the standard headers for this project */
#include "headers.h"

/* finally, the main routine */

int
main(int argc, char **argv) {
  /* this takes two file names - the HDF input file name
     and the netCDF output file name.  It will complain
     if the filenames are the same.
  */

  int status;
  int i;
  int ncid;
  int ndims, nvars, ngatts, unlimdimid;
  int point_p, swath_p, grid_p;
  char *hdfname, *netcdfname;
  long bufSize;


  if(argc != 3) {
    fprintf(stderr, "usage: hdf52netcdf hdf-input-file netcdf-output-file\n");
    exit(-1);
  }
  hdfname = argv[1];
  netcdfname = argv[2];

  if(!strcmp(hdfname, netcdfname)) {
    fprintf(stderr, "Input and output files must be different.  Sorry!\n");
    exit(-1);
  }

  /* First open output file */
  SS(nc_create(netcdfname, NC_CLOBBER, &ncid));

  /* Then check the input file to see if it's HDFEOS5, and if so is it a
     Point, Swath, or Grid file.
  */
  SS(point_p = HE5_PTinqpoint(hdfname, NULL, &bufSize));
  SS(swath_p = HE5_SWinqswath(hdfname, NULL, &bufSize));
  SS(grid_p = HE5_GDinqgrid(hdfname, NULL, &bufSize));

  if(!point_p && !swath_p && !grid_p) {
    fprintf(stderr, "%s is not an HDF-EOS5 Point/Swath/Grid file.  Sorry!\n",
	    hdfname);
    exit(-1);
  }

  /* Technically, it could be more than one, but as a first whack we're
     insisting it be exactly one of them. */
  if((!!point_p + !!swath_p + !!grid_p) > 1) {
    fprintf(stderr, "%s is an HDF-EOS5 file, but has", hdfname);
    if (point_p)
      fprintf(stderr, " Point and");
    if (swath_p)
      fprintf(stderr, " Swath%s", (grid_p ? "" : " and"));
    if (grid_p)
      fprintf(stderr, " Grid");
    fprintf(stderr, " components - too complicated for me.  Sorry!\n");
    exit(-1);
  }

  if(point_p)
    convert_point(hdfname, netcdfname, ncid);
  else if (swath_p)
    convert_swath(hdfname, netcdfname, ncid);
  else
    convert_grid(hdfname, netcdfname, ncid);

  /* rashly assuming we won... */
  exit(0);
}

/* The real converter functions */

void convert_point(char *hdfname, char *netcdfname, int ncid)
{
  fprintf(stderr, "Sorry, I don't do point files, either.\n");
  exit(-1);
}



